# YASARA MOVIE
# TOPIC:    1. General
# TITLE:    1.1. Working with YASARA
# REQUIRES: View 20.5.1
# AUTHOR:   Elmar Krieger
# LICENSE:  GPL
# DESCRIPTION: A tutorial explaining how to work with YASARA to new users. Many thanks to Sven Geier for his 'Planetary' background (more at www.sgeier.net/fractals).

# Change working directory to the place of this macro
# (so that we don't have to specify paths when loading stuff).
CD (MacroDir)
OnError Continue
BallStickRadius 50,50
StickRadius 50
AtomSize 100
LightSource Alpha=040,Gamma=066,Ambience=085,Shadow=065
ColorBG 000040,30c0ff

# Fresh start
Start:
Clear
# Left handed coordinate system
CoordSys Left
Projection perspective
HideMessage
UserInput Off

# Don't show console and head-up display
HUD Off
Console Off
MarkAtom None
#OK
# Load Yami and texture for board below
LoadSce yami
LoadPNG board
# Create the sky sphere using 6 views (xei is a custom format, jpg is also possible)
ShowSkySphere space131.xei
PosObj SkySphere,Z=990
AutoRotateObj SkySphere,X=1
PolygonPar Reflection=20

# MakeImageObj MouseUse,3,8.5,8
SwitchObj MouseUse,off

# Show Yami as a piece of stone
# (Stone atom texture only available starting with YASARA Model)
if Model and not Movie
  AtomTexture 5
Style Ball
# Hide Yami's eyes
HideRes UNK
Color Grey
yami='Yami Board'

# Let 'Welcome to' and 'YASARA' show up..
AutoPosObj Welcome,Y=4.5,Z=50,Steps=200,Wait=No
AutoPosObj YASARA,Y=-4.5,Z=50,Steps=200
AutoOriObj Welcome YASARA,Beta=0,Steps=180,Wait=No
AutoPosObj Welcome,X=0,Y=16,Z=68,Steps=180,Wait=No
AutoPosObj YASARA,X=0,Y=-8,Z=52,Steps=180

# Let Yami follow, throwing the others out of the way
AutoMoveObj (yami),Y=0.5
Wait 80
AutoMoveObj YASARA,Y=-0.1,Z=-0.4
AutoRotateObj YASARA,X=-3
# Take snapshot here, Eliza!
Wait 25
# Bring the skysphere back to a normal view
AutoRotateObj SkySphere,X=0
AutoPosObj SkySphere,Z=250,Steps=40,Wait=No
AutoOriObj SkySphere,0,0,0,Steps=40,Wait=No
AutoMoveObj Welcome,Y=1
AutoRotateObj Welcome,X=5
Wait 15
AutoMoveObj (yami),Y=0
Wait 45
DelObj Welcome YASARA
AutoRotate Y=1
Wait 100

# Show Yami styles
for i=1 to 84
  HideRes (i)
  ShowSecRes (i),Ribbon
  Wait 1
AtomTexture 1
Stick
for i=1 to 84
  ColorRes (i),Element
  if i==17 or i==30
    # The Eyes
    ShowAtom SideChain CA Res (i)
    ColorAtom CB Res (i),Grey
    ColorAtom CA Res (i),Red
    HideAtom HB Res (i)
    if i==17
      eyeatom=1010
    else
      eyeatom=1009
    ShowAtom (eyeatom)
    BallAtom (eyeatom)
    ColorAtom (eyeatom),316
  if i==23 or i==54
    # The sensors
    ShowAtom SideChain CA Res (i)
    HideAtom HB HG HD HE Res (i)
  if i==33 or i==83
    # The feet
    ShowAtom SideChain CA Res (i)
    BallAtom SideChain Res (i)
    HideAtom HB HD1 HE3 Res (i)
    ColorAtom NE1 Res (i),Cyan
  Wait 1
Wait 92
AutoRotate Y=0
AutoPos Z=26,Steps=60

# Greeting
greeting="Hi "+FirstName+"! I'm Yami, your guide through the microcosm..."
ShowMessage (greeting)

# Shake Yami's head
for i=1 to 3
  AutoOriObj Yami,Alpha=18,Steps=30
  AutoOriObj Yami,Alpha=-10,Steps=30
  AutoOriObj Yami,Alpha=0,Steps=15
ShowMessage "Most of the time, you can use the back- and forward-icons in the top right corner to restart or skip a section."
Wait ContinueButton
DelObj MouseUse
AutoPos X=25,Y=-8.5,Z=66,Steps=100,Wait=No
AutoOri Alpha=0,Beta=50,Gamma=0,Steps=100

# Load the menu with input options to explain
LoadSceKeepSky 'yami2'
MoveObj 3-8,X=-50
AutoMoveObj 3-8,X=0.5
Wait 100
AutoMoveObj all,X=0

# Wait until user selects an option
ShowMessage "Please click one circle to get specific usage instructions..."
do
  Wait 2
  opt = MarkAtom
while opt<Atoms-3
HideMessage
# The last four atoms in the soup are our options, so opt is now 1..4
opt=opt-Atoms+4
# Let options fly away
AutoRotateObj Option(opt),X=1,Y=3,Z=2
Wait 60
AutoRotateObj Choices,Y=0.5
AutoMoveObj Choices,Z=-0.5
AutoMoveObj Option? Methane,Y=-0.2
Wait 200
DelObj not 1-2 SkySphere
# Move Yami to the center
AutoRotate Y=-0.5
AutoPos X=0,Steps=100
AutoRotate Y=0

if opt==1
  # Instructions for PC/Mac with mouse 
  textlist="Keep the left mouse button pressed and move the mouse to rotate...",
           "Keep the right mouse button pressed and move the mouse to slide along the Z-axis...",
           "Keep both (or the middle) button(s) pressed and move the mouse to slide along the X- and Y-axes...",
           "To rotate around the Z-axis, you have many options. You can keep the left mouse button pressed and draw a circle...",
           "Or you can use the mouse wheel (click 'Options > Input devices > Mouse wheel command' to assign other functions)."
  image=0

if opt==2
  # Instructions for Mac with mighty mouse
  textlist="Note that the MightyMouse has a few technical problems that are best avoided by using a normal 3-button wheel mouse instead...",
           "Keep the left mouse button pressed and move the mouse to rotate...",
           "Keep the right mouse button pressed and move the mouse to slide along the Z-axis...",
           "Keep the two side-buttons pressed and move the mouse to slide along the X- and Y-axes...",
           "If you prefer to use the two side-buttons for something else, you can also use the scroll-knob instead..."
  image='mightymouse'
  
if opt==3
  # Instructions for MacBook with trackpad
  textlist="Keep the trackpad pressed strongly while moving a single finger to rotate...",
           "Move two fingers on the trackpad softly to slide along the X- and Y-axes...",
           "(If this did not work, click Options > Input devices > Mouse wheel command > Move along XY-axes).",
           "Use the same two fingers to slide along Z and rotate around the Z-axis (pinch gesture)..."
           "Add a third finger to rotate around X- and Y-axes, giving you six degrees of freedom.",
           "Throughout all tutorials, 'right-click' means 'touch the TrackPad with two fingers'."
  image='trackpad'
   
if opt==4
  # Instructions for tablet or smartphone
  # Load the gesture images, optimized for 16:10 screens common on tablets
  startpos='256,-320,512,320'
  for i=1 to 5
    ShowMessage 'Please wait, loading graphics. ((i-1)*20)% complete.'
    Wait 1
    LoadPNG gesture(i)
    ShowImage gesture(i),(startpos),Priority=1
  UserInput On
          # The left finger shows how to rotate about X- and Y-axes
  comlist='1, 900,-250,1280,800',          50,'ShowMessage "Hold down and move a single finger to rotate about the X- and Y-axes..."',
          '1, -256,-250,1280,800',        100,'AutoRotate Y=-1',
          '1, 320,-250,1280,800',          50,'AutoRotate Y=1',
          '1, 320,0,1280,800',             50,'AutoRotate X=1,Y=0',
          '1, 320,-680,1280,800',         100,'AutoRotate X=-1',
          '1, 320,-340,1280,800',          50,'AutoRotate X=1',
          '1, 900,-340,1280,800',          50,'AutoRotate X=0,Y=1',
          '',                              -1,'Wait',
          # The right finger shows how to translate along X- and Y-axes
          '2, -1160,-250,1280,800',        50,'ShowMessage "Hold down and move a second finger to translate along the X- and Y-axes..."',
          '2, -120,-250,1280,800',        100,'AutoMove X=-0.3',
          '2, -580,-250,1280,800',         50,'AutoMove X=0.3',
          '2, -580,0,1280,800',            50,'AutoMove X=0,Y=0.25',
          '2, -580,-680,1280,800',        100,'AutoMove Y=-0.25',
          '2, -580,-340,1280,800',         50,'AutoMove Y=0.25',
          '2, -1160,-340,1280,800',        50,'AutoMove X=0.3,Y=0',
          '',                              -1,'Wait',
          # Do both at the same time
          '2, -1160,-340,1280,800',        -1,'ShowMessage "Of course you can do both at the same time..."',
          '1, 384,-340,1280,800',         -50,'AutoRotate Y=-1',
          '2, -640,-340,1280,800',         50,'AutoMove X=-0.25',
          '1, 900,-340,1280,800',         -50,'AutoRotate Y=1',
          '2, -1160,-340,1280,800',        50,'AutoMove X=0.25',
          '',                              -1,'Wait',
          # The left hand shows the pinch gesture
          '1 gesture2,(startpos),Alpha=0', 50,'pass',
          '3, 234,-120,1280,800',          50,'ShowMessage "Hold down and move two fingers to translate along the X- and Y-axes.."',
          '3, 724,-120,1280,800',          50,'AutoMove X=-0.3',
          '3,-256,-120,1280,800',         100,'AutoMove X=0.3',
          '3, 234,-120,1280,800',          50,'AutoMove X=-0.3',
          '3, 234,-240,1280,800',          50,'AutoMove X=0,Y=-0.15',
          '3, 234,0,1280,800',            100,'AutoMove X=0,Y=0.15',
          '3, 234,-120,1280,800',          50,'AutoMove Y=-0.15',
          '',                              -1,'Wait',
          '5, -238,-95,1200,750',          -1,'ShowMessage "You can also translate along and rotate about the Z-axis by pinching the two fingers and rotating the hand..."',
          '5, -278,-120,1280,800',         75,'AutoMove Z=1',
          '5, -238,-95,1200,750',          75,'AutoMove Z=-1',
          '5, -278,-120,1280,800',         -1,'AutoMove Z=0',
          '5, -278,-120,1280,800',         90,'AutoRotate Z=-1',
          '5, -238,-95,1200,750',          90,'AutoRotate Z=1',
          '',                              -1,'Wait',
          '5, 308,260,176,110,Alpha=0',    50,'AutoRotate Z=0',
          # Show six degrees of freedom with three fingers
          '3, 624,-120,1280,800',         -50,'ShowMessage "Now add a third finger to rotate about the X- and Y-axis, and you got access to all six degrees of freedom."',
          '2, -800,-250,1280,800,Alpha=100',50,'AutoRotate X=0.2,Y=0.6,Z=0.4',
          '3, 624,-120,1280,800',         430,'Wait',
          '2 gesture3,(startpos),Alpha=0', 50,'pass',
          # Show left click
          '1, 450,-260,1024,640,Alpha=100',50,'ShowMessage "When a tutorial asks you to <click> or <left-click>, that means a short tap [shorter than 0.35 seconds]."',
          '1, 320,-340,1280,800',          10,'pass',
          '1, 450,-260,1024,640',          10,'Wait',
          '1, 320,-340,1280,800',          10,'MarkAtom 1010',
          '1, 450,-260,1024,640',          10,'ShowMessage "Tap on one of my eyes to mark it.."',
          '',                              -1,'Wait',
          # Show right click
          '1, 450,-260,1024,640',          50,'ShowMessage "When a tutorial asks you to <right-click>, that means a long tap [longer than 0.65 seconds]."',
          '1, 320,-340,1280,800',          10,'pass',
          '1, 320,-340,1280,800',          75,'pass',
          '1, 450,-260,1024,640',          10,'Wait',
          '1, 320,-340,1280,800',          10,'ShowMessage "Make sure that one of my eyes is marked, then do a long tap on it to open the atom context menu..."',
          '1, 320,-340,1280,800',          75,'pass',
          '1, 450,-260,1024,640',          10,'Wait',
          # Show alternative right-click
          '1,(startpos),Alpha=0',         -50,'MarkAtom 1010',
          '4, -62,-220,1024,640',          50,'ShowMessage "A faster way to <right-click> is to tap with two fingers, with the marked atom in between."',
          '4, -192,-300,1280,800',         10,'pass',
          '4, -62,-220,1024,640',          10,'Wait',
          '4, -192,-300,1280,800',         10,'pass',
          '4, -62,-220,1024,640',          10,'ShowMessage "Try a two finger tap around my marked eye to activate the atom context menu..."',
          '',                              -1,'Wait',
          # Explain the virtual keyboard
          '4, 346,73,80,50',               50,'ShowMessage "YASARA comes with its own virtual keyboard. Tap Options > Input devices, and make sure that the virtual keyboard is enabled."',
          '',                              -1,'Wait',
          '',                              -1,'ShowMessage "Tap Options > Input devices > Virtual keyboard: Layout to choose your favorite keyboard layout."',
          '',                              -1,'Wait',
          '',                              -1,'ShowMessage "*Note* that you can use the pinch gesture to zoom the graphical user interface, so that it fits your fingers exactly."',
          '',                              -1,'Wait',
          '',                              -1,'ShowMessage "Tap Options > Input devices > Virtual keyboard: Parameters to configure the virtual keyboard."',
          '',                              -1,'Wait',
          '2, 0,-260,1024,640,Alpha=100',  50,'ShowMessage "To show the virtual keyboard, tap on the left side, close to the screen border..."',
          '2, 0,-340,1280,800',            10,'pass',
          '2, 0,-260,1024,640',            10,'Wait',
          '2,(startpos),Alpha=0',          50,'ShowMessage "Test the virtual keyboard: press the function keys F1 to F8 to quickly change the scene style..."',
          '',                              -1,'Wait',
          '',                              -1,'ShowMessage "To hide the virtual keyboard, press the <Hide> key in its top right corner..."',
          '',                              -1,'Wait',
          '1, 0,-260,1024,640,Alpha=100',  50,'ShowMessage "If you know in advance that you only want to press a single key, then tap on the right side. The keyboard will disappear again."',
          '1, -256,-340,1280,800',         10,'pass',
          '1, 0,-260,1024,640',            10,'Wait',
          '1,(startpos),Alpha=0',          50,'ShowMessage "If a tutorial tells you to press the <Ctrl>, <Alt> or <Space> keys, you do *not* have to show the virtual keyboard..."',
          '',                              -1,'Wait',
          '',                              -1,'ShowMessage "...because the bottom key row is always active. Just tap near the bottom of the screen."',
          '',                              -1,'Wait'
  for i=1 to count comlist step 3
    delay=comlist(i+1)
    com=comlist(i+2)
    if comlist(i)!=''
      AutoMoveImage gesture(comlist(i)),Steps=(abs delay)
    if com=='Wait'
      if delay>0
        Wait (delay)
      # Wait until user presses the Continue button
      AutoMove 0,0,0
      AutoRotate 0,0,0
      Wait ContinueButton
      # Move Yami back to start
      AutoOri 0,310,0,Steps=50,Wait=No
      AutoPos 0,-8.5,66,Steps=50
    else
      (com)
      if delay>0
        Wait (delay)
  DelImage !Board
  image=0
LoadSceKeepSky 'yami'
DelObj Welcome YASARA  
UserInput On
PosOriObj Yami, X=-1.542, Y=2.941, Z=68.020, Alpha=0.526, Beta=-2.480, Gamma=3.574
PosOriObj Board, X=1.542, Y=-19.941, Z=63.980, Alpha=90.840, Beta=-1.421, Gamma=-0.015
if image
  # Show expected MacOSX system preferences
  UserInput Off
  LoadPNG (image)
  SwitchObj MouseUse,On
  PosObj MouseUse,20,0.8,5
  AutoRotateObj MouseUse,Y=-2
  AutoPosObj MouseUse,X=0,Steps=180
  AutoRotateObj MouseUse,0,0,0
  ShowMessage "This tutorial assumes that the system preferences shown above have been set..."
  Wait ContinueButton
  AutoRotateObj MouseUse,X=1
  AutoMoveObj MouseUse,Y=-0.3
  Wait 50
  UserInput On
DelObj MouseUse
# Explain mouse movements
for text in textlist
  ShowMessage (text)
  Wait ContinueButton

# Explain head-up display
AutoPos -1,8,12,Steps=100,Wait=No
AutoOri -50,0,0,Steps=100
DelObj SkySphere
LoadPNG planetary
ShowImage planetary
PolygonPar Reflection=0
ShowMessage "Press the <Insert> or <I> key to toggle the head-up display (HUD) on and off..."
Wait ContinueButton
if Dynamics
  ShowMessage "Press <Ctrl>+<Insert> (or +<I>) to switch between scene content and simulation parameters..."
  Wait ContinueButton
ShowMessage "Click on one of the atoms in my feet. You will see its properties in the left head-up display (HUD)..."
HUD Obj
Wait ContinueButton
ShowMessage "Press <PageUp> and <PageDown> to cycle through the atoms in the soup..."
Wait ContinueButton

# Explain distance, angle and dihedral angle indicators
for text in "Keep <Ctrl> pressed and click on another atom. The distance between the white and red fireflies is shown in the HUD...",
            "Keep <Ctrl> pressed and click on a 3rd atom. The angle between the white, green and red fireflies is now also shown...",
            "Keep <Ctrl> pressed and click on a 4th atom. The dihedral angle between the white,blue,green and red fireflies is shown..."
  ShowMessage (text)
  Wait ContinueButton

# Explain context menu and <Alt> command repeat
MarkAtom 994
for text in "Right-click on the atom marked with white fireflies to bring up an atom context menu. Select Color>Residue and 'Yellow'...",
            "You can repeat the last command by holding down <Alt>. So keep <Alt> pressed and click on my other foot...",
            "If nothing happened, your window-manager hijacks <Alt>+click. Use <Tab>+click instead and read the docs...",
            "Click on any atom in my feet to mark it, then right-click and Select > in sphere around atom. Pull the sphere around my foot.",
            "You now permanently selected atoms. Right-click on any selected atom, then Color > Element to revert the color back to normal.",
            "Click Edit > Unselect > All to remove the permanent selection. Try also the box and area selection icons in the top menu line."
  ShowMessage (text)
  Wait ContinueButton
UnselectAll

# Explain centered rotation
MarkAtom 1010
AutoPos 2,9,68,Steps=100,Wait=No
AutoOri 216,180,0,Steps=100
for text in "Keep <Ctrl> plus the left mouse button pressed and move the mouse to globally center the rotation on the marked atom...",
            "Alternatively <Ctrl>+double-click on an atom to zoom in and center the rotation on its residue. To undo this global centering...",
            "...either center on a different atom using <Ctrl> as just shown, or click Edit > Center > Stop global centering."
  ShowMessage (text)
  Wait ContinueButton
UnselectAll

# Explain styles
AutoPos 5,-4,68,Steps=100,Wait=No
AutoOri 40,0,48,Steps=100
ShowMessage "Press the function keys <F1> to <F7> to quickly choose a scene style. Press <F8> several times to show the side-chains..."
Wait ContinueButton

# Explain sequence selector
AutoPos 5,-4,68,Steps=100,Wait=No
AutoOri 40,0,48,Steps=100
Style BallStick
Color Element
for text in "Move the pointer to the bottom of the window. The sequence selector appears. Click on the top-left pin icon to fix it...",
            "Click on any residue in the sequence selector to mark it...",
            "Note that the sequence selector shows the secondary structure: 'H' for helix, 'E' for strand, 'T' for turn and 'C' for coil...",
            "Move the mouse pointer on top of the sequence selector and type 'F','L','A' to find the amino acid sequence Phe-Leu-Ala...",
            "Right-click on the marked 'Phe' in the sequence selector to bring up a residue context menu and select Style>Ball>Residue...",
            "<Alt>(or <Tab>)+click on any residue in the sequence selector to repeat the last command...",
            "<Ctrl>+click on any residue in the sequence selector to zoom in on the residue..."
  ShowMessage (text)
  Wait ContinueButton

# Explain scene content HUD
SceneContent:
Clear
AtomTexture 1
LoadSce yami3
LoadPNG board
LoadPNG planetary
ShowImage planetary
HUD Obj
textlist="Try the secondary structure morpher to interpolate between real and ideal: Click View > Show secondary structure > Perfection...",
         "If you look at the top-right scene content, you'll notice that I consist of two peptide chains stored in objects 1 and 3...",
         "Click in the 'VISiblity' column of the scene content to switch individual objects on and off...",
         "Right-click in the 'VISiblity' column to switch the clicked object on and all others off...",
         "Click in the 'Name' column of the scene content to browse through objects, molecules, residues and atoms...",
         "Right-click in the 'Name' column to bring up a context menu and modify the scene content...",
         "Again, use <Alt>(or <Tab>)+click in the 'Name' column to repeat the last command...",
         "<Ctrl>+click in the 'Name' column to grab a single object for movement with the mouse...",
         "<Ctrl>+click a second time on the name of the grabbed object to move the entire scene again...",
         "You can also use <Shift> and <Ctrl>+<Shift> to grab another object or all of them. Look at the 'Obj' field in the bottom line..."
texts=count textlist
if not Model
  # Grabbing only works in YASARA Model, show only the first three instructions in View
  texts=6
for i=1 to texts
  ShowMessage (textlist(i))
  Wait ContinueButton

# Explain translation and rotation keys
Keyboard:
Clear
HUD Off
LoadSce yami
LoadPNG board
LoadPNG planetary
ShowImage planetary
DelObj 3-5
Move Y=60
AutoMoveObj Board,Y=-0.5
AutoRotateObj Board,X=2
AutoRotateObj Yami,Y=6
AutoMoveObj Yami,Y=0.4
Wait 15
DelObj Board
DelImage board
Wait 15
AutoRotateObj Yami,X=3,Y=0
Wait 30
AutoRotateObj Yami,X=0,Z=5
AutoPosObj Yami,X=110,Y=170,Z=980,Steps=200
steps=200
AutoPosObj Yami,X=0,Y=-12,Z=100,Steps=(steps),Wait=No
# Zoom in on the planet. This would be much easier with 'AnimateImage', but
# this command is not available in the free YASARA View.
for i=1 to steps
  step=(0.+i)/steps
  ShowImage planetary,X=(465.*step),Y=(35.*step),Width=((1.-step)*1024+step*320),Height=((1.-step)*768+step*240)
  Wait 1
# Load the keyboard
LoadYOB keyboard
LoadPNG keyboard,TransCol=Magenta
PosObj keyboard,0,-418,920
for text in "Sometimes the mouse is not accurate enough to move the objects where you want them. Here are some keys to use...",
            "The X-axis runs horizontally. Use the keys marked red to move along and rotate about this axis...",
            "Press <1> to <9> to change the speed of movements, and <Ctrl>+<1> to <9> to change the speed of rotations...",
            "The Y-axis runs upwards, the Z-axis runs into the screen. Use the keys marked green and blue for these axes..."
  ShowMessage (text)
  AutoPosObj Yami,52.4,50.6,207,Steps=100,Wait=No
  AutoPosObj keyboard,27.2,-5,152,Steps=100,Wait=No
  AutoRotate 0,0,0
  AutoRotateObj All,0,0,0
  AutoOriObj Yami,0,0,0,Steps=100,Wait=No
  AutoOriObj keyboard,56.2,0,0,Steps=100
  # Let Yami jump
  for i=1 to 2
    for j=0 to 180 step 6
      PosObj Yami,Y=(50.60+sin (j)*10)
      if i==2
        OriObj Yami,Alpha=(j*2)
      Wait 1
  Wait ContinueButton

# Explain the console
AutoRotateObj All,0,0,0
AutoPos -11,-27,38,Steps=150
ConsolePar Font=Large,Height=50
for text in "If you prefer a text interface, just press <Space> to bring up the console...",
            "Use <CursorUp> and <CursorDown> to cycle through the past commands and <Space> to extend the console size...",
            "Text you mark in the console is automatically copied to the clipboard. Press the middle mouse button or <Ctrl>+<V> to paste.",
            "That's it for this time! I wish you a lot of scientific insight and of course fun with YASARA..."
  ShowMessage (text)
  Wait ContinueButton
AutoPos -11,55.8,77,Steps=150
AutoRotate Z=1
AutoMove Y=0.6,Z=1
Wait 200

# LOAD SCENE BUT KEEP SKYSPHERE
# =============================
def LoadSceKeepSky scefilename
  # Show the current skysphere orientation to avoid a jump
  Wait 1
  posorilist() = PosOriObj SkySphere
  # Add sce.gz to handle old YASARA installations which also have leftovers without .gz 
  LoadSce (scefilename).sce.gz
  ShowSkySphere space131.xei
  PosOriObj SkySphere,(posorilist)

"""
# Create the option screen. Since this requires features not present in YASARA View,
# we simply save the result as a scene.  
LoadSce yami
LoadPNG board
DelObj not 1-2
PosOriAll X=25,Y=-8.5,Z=66,Alpha=0,Beta=50,Gamma=0
choicelist='PC or Mac with mouse','Mac with mighty mouse','MacBook with trackpad','Tablet or smartphone'
colorlist='ff0000','ff4000','ff8000','ffff00'
choices=count choicelist
textobj = MakeTextObj Name=Choices,Width=60,Height=21
for i=1 to choices
  y=((0.5*(choices+1)-i)*6+1)
  z=55
  color=colorlist(i)
  # Create the atom to mark
  obj1 = BuildAtom Carbon
  ColorObj (obj1),(color)
  # Create the donut around it
  obj2 = ShowTorus LargeRadius=2,LargeEdges=32,SmallRadius=0.5,SmallEdges=10,Color=(color)
  NameObj (obj2),'Option(i)'
  PosObj (join obj),-28,(y),(z)
  # Create the text
  Font Arial,Height=2,Color=(colorlist(i)),Depth=1.0,DepthCol=800000
  PosText 0%,(85.*(choices-i)/(choices-1)+3)%,Left
  Print (choicelist(i))
PosObj (textobj),8,1,(z)
JoinObj Methane,4
NumberObj all,1
SaveSce yami2.sce.gz
"""
